@@ -86,8 +86,8 @@ namespace ost {
 #define	AUDIO_SIGNED_LINEAR_RAW	1
 #define	AUDIO_LINEAR_CONVERSION 1
 #define	AUDIO_CODEC_MODULES	1
-
-
+#define	AUDIO_LINEAR_FRAMING	1
+#define	AUDIO_NATIVE_METHODS	1
 
 class __EXPORT AudioCodec;
 class __EXPORT AudioDevice;
@@ -542,6 +542,16 @@ public:
 	 */
 	static bool swapEndian(Encoding encoding, void *buffer, unsigned number);
 
+	/**
+	 * Optionally swap endian of encoded audio data based on the
+	 * audio encoding type, and relationship to native byte order.
+	 *
+	 * @param info source description of object.
+	 * @param buffer of audio data.
+	 * @param number of bytes of audio data.
+	 */
+	static void swapEncoded(Info &info, Encoded data, size_t bytes);
+
        /**
          * Optionally swap endian of audio data if the audio source
 	 * description byte order is different from the machine's native
@@ -910,6 +920,16 @@ public:
 	 */
 	virtual ssize_t putBuffer(Encoded data, size_t size) = 0;
 
+	/**
+	 * Puts raw data and does native to refined endian swapping
+	 * if needed based on encoding type and local machine endian.
+	 *
+	 * @param data to put.
+	 * @param size of data to put.
+	 * @return number of bytes actually put.
+	 */
+	ssize_t putNative(Encoded data, size_t size);
+
         /**
          * Abstract interface to get raw data.
          *
@@ -918,8 +938,17 @@ public:
          * @param size of data to get.
          */
 	virtual ssize_t getBuffer(Encoded data, size_t size) = 0;
+
+	/**
+	 * Get raw data and assure is in native machine endian.
+	 *
+	 * @return data received in buffer.
+	 * @param data to get.
+	 * @param size of data to get.
+	 */
+	ssize_t getNative(Encoded data, size_t size);
 };
-	
+
 /**
  * The AudioBuffer class is for mixing one-to-one
  * soft joins.
@@ -1806,6 +1835,15 @@ public:
 	 */
 	virtual unsigned putSamples(Linear buffer, unsigned count) = 0;
 
+	/**
+	 * Copy linear samples to an audio device from native endian.
+	 *
+	 * @param buffer to linear audio data.
+	 * @param count of audio samples to play.
+	 * @return number of audio samples played.
+	 */
+	unsigned putNativeSamples(Linear buffer, unsigned count);
+
         /** 
          * Copy linear samples from an audio device through its virtual.
          *
@@ -1815,6 +1853,15 @@ public:
          */
 	virtual unsigned getSamples(Linear buffer, unsigned count) = 0;
 
+	/**
+	 * Copy linear samples from an audio device into native endian.
+	 *
+	 * @param buffer for recording.
+	 * @param count of audio samples to record.
+	 * @return number of audio samples recorded.
+	 */
+	unsigned getNativeSamples(Linear buffer, unsigned count);
+
 	/**
 	 * Copy audio encoded in the currently selected encoding for
 	 * the audio device.
