@@ -1254,7 +1254,7 @@ unsigned AudioFile::getLinear(Linear addr, unsigned samples)
 
 	if(getEncoding() == pcm16Mono)
 	{
-		count = getBuffer((Encoded)addr, samples * 2);
+		count = getNative((Encoded)addr, samples * 2);
 		if(count < 0)
 			return 0;
 		return count / 2;
@@ -1292,7 +1292,7 @@ unsigned AudioFile::putLinear(Linear addr, unsigned samples)
 
 	if(getEncoding() == pcm16Mono)
 	{
-		count = putBuffer((Encoded)addr, samples * 2);
+		count = putNative((Encoded)addr, samples * 2);
 		if(count < 0)
 			return 0;
 		return count / 2;
