@@ -634,6 +634,27 @@ Audio::Level Audio::getPeak(Info &info, void *buffer, unsigned samples)
 	return -1;
 }
 
+void Audio::swapEncoded(Info &info, Encoded buffer, size_t bytes)
+{
+	char buf;
+
+	if(!isLinear(info.encoding))
+		return;
+
+	if(!info.order || info.order == __BYTE_ORDER)
+		return;
+
+	// options for machine optimized should be inserted here
+
+	bytes /= 2;
+	while(bytes--)
+	{
+		buf = buffer[1];
+		buffer[1] = *buffer;
+		*buffer = buf;
+		buffer += 2;		
+	}
+}
 
 bool Audio::swapEndian(Encoding encoding, void *buffer, unsigned samples)
 {
